@@ -1,4 +1,7 @@
-pub mod comment;
+extern crate liquid;
+extern crate serde;
+
+pub mod filters;
 pub mod helpers;
 mod messages;
 #[allow(non_upper_case_globals)]
@@ -6,19 +9,30 @@ mod messages_data;
 mod nodes;
 #[allow(non_upper_case_globals)]
 mod nodes_data;
-pub mod template;
 
 pub use messages::*;
 pub use nodes::*;
 
-pub fn nodes() -> NodeList {
+pub fn nodes() -> &'static [&'static Node] {
     nodes_data::ALL_NODES
 }
 
-pub fn messages() -> MessagesList {
+pub fn messages() -> &'static [&'static Message] {
     messages_data::ALL_MESSAGES
 }
 
+mod liquid_template;
+pub use liquid_template::LiquidTemplate;
+
+pub mod reexports {
+    pub mod liquid {
+        pub use liquid_core::value;
+    }
+    pub mod serde {
+        pub use serde::{ser::SerializeStruct, Serialize, Serializer};
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use crate::NodeFieldType;
@@ -29,16 +43,6 @@ mod tests {
     fn test_nodes() {
         let nodes = nodes();
         assert!(nodes.len() > 0);
-
-        for node in nodes {
-            for node_field in node.fields {
-                assert_eq!(
-                    &node_field.node, node,
-                    "field {} of node {} refers to a different node ({})",
-                    node_field.snakecase_name, node.camelcase_name, node_field.node.camelcase_name
-                );
-            }
-        }
     }
 
     #[test]
@@ -121,18 +125,5 @@ mod tests {
     fn test_messages() {
         let messages = messages();
         assert!(messages.len() > 0);
-
-        for message in messages {
-            for message_field in message.fields {
-                assert_eq!(
-                    &message_field.message,
-                    message,
-                    "field {} of message {} refers to a different message ({})",
-                    message_field.snakecase_name,
-                    message.camelcase_name,
-                    message_field.message.camelcase_name
-                );
-            }
-        }
     }
 }
